@@ -31,6 +31,7 @@ import java.net.MalformedURLException;
 import java.net.URL;
 
 import java.util.HashSet;
+import java.util.Properties;
 import java.util.Set;
 
 import com.sun.javadoc.ClassDoc;
@@ -54,6 +55,7 @@ public class ExternalDocSet
    }
 
    private Set packageNames = new HashSet();
+   private boolean javadocCompatible;
 
    public void load(File targetDirectory)
       throws IOException, MalformedURLException
@@ -84,14 +86,56 @@ public class ExternalDocSet
       else {
          throw new FileNotFoundException(packageListURL.toString());
       }
+
+      URL gjdocPropertiesURL = new URL(packageListDirURL,
+                                       "gjdoc.properties");
+      InputStream propertiesIn = gjdocPropertiesURL.openStream();
+      if (null != in) {
+         Properties properties = new Properties();
+         properties.load(propertiesIn);
+         propertiesIn.close();
+         
+         String gjdocCompatProperty = properties.getProperty("gjdoc.compat");
+         if (null != gjdocCompatProperty) {
+            javadocCompatible = "true".equals(properties.getProperty("gjdoc.compat"));
+         }
+         else {
+            javadocCompatible = true;
+         }
+      }
+      else {
+         javadocCompatible = true;
+      }
+   }
+
+   public String getPackageDocURL(String packageName)
+   {
+      try {
+         URL packageURL = new URL(docSetDirectoryURL,
+                                  packageName.replace('.', '/'));
+         return packageURL.toString();
+      }
+      catch (MalformedURLException e) {
+         // This should not happen since we know that packageName is a
+         // proper Java identifiers, so the resulting URL can't be
+         // invalid
+         throw new RuntimeException(e);
+      }
    }
 
    public String getClassDocURL(String packageName, String typeName)
-      throws MalformedURLException
    {
-      URL fileURL = new URL(docSetDirectoryURL,
-                            packageName.replace('.', '/') + "/" + typeName + ".html");
-      return fileURL.toString();
+      try {
+         URL fileURL = new URL(docSetDirectoryURL,
+                               packageName.replace('.', '/') + "/" + typeName + ".html");
+         return fileURL.toString();
+      }
+      catch (MalformedURLException e) {
+         // This should not happen since we know that packageName and
+         // typeName are proper Java identifiers, so the resulting URL
+         // can't be invalid
+         throw new RuntimeException(e);
+      }
    }
 
    protected void readPackages(InputStream in)
@@ -110,4 +154,9 @@ public class ExternalDocSet
    {
       return packageNames;
    }
+
+   public boolean isJavadocCompatible()
+   {
+      return javadocCompatible;
+   }
 }
