@@ -99,6 +99,37 @@ public class ClassDocImpl
 
    private Map findClassCache = new HashMap();
 
+   public ClassDoc findClass(String className, String dimension)
+   {
+      ClassDoc cached = (ClassDoc)findClassCache.get(className + dimension);
+      if (null != cached) {
+         return cached;
+      }
+      else {
+         ClassDoc classDoc = findClass(className);
+
+         if (null!=classDoc) {
+            try {
+               if (classDoc.dimension().equals(dimension)) {
+                  return classDoc;
+               }
+               else {
+                  ClassDoc rc = (ClassDoc) ((WritableType)classDoc).clone();
+                  ((WritableType)rc).setDimension(dimension);
+                  findClassCache.put(className + dimension, rc);
+                  return rc;
+               }
+            }
+            catch (CloneNotSupportedException e) {
+               throw new RuntimeException(e);
+            }
+         }
+         else {
+            return null;
+         }
+      }
+   }
+
    public ClassDoc findClass(String className) 
    {
       String qualifiedName = Main.getRootDoc().resolveClassName(className, this);
@@ -249,7 +280,7 @@ public class ClassDocImpl
    public String typeName() { return name(); }
    
    public String qualifiedTypeName() { 
-      return (containingPackage()!=null && containingPackage()!=PackageDocImpl.DEFAULT_PACKAGE)?(containingPackage().name()+"."+name()):(name()); 
+      return (containingPackage()!=null && !containingPackage().equals(PackageDocImpl.DEFAULT_PACKAGE))?(containingPackage().name()+"."+name()):(name()); 
    }
 
    public String qualifiedName() { return qualifiedTypeName(); }
@@ -683,21 +714,9 @@ public class ClassDocImpl
 	 typeName=typeName.substring(0,ndx).trim();
       }
 
-      ClassDoc classDoc = findClass(typeName);
-      if (null!=classDoc) {
-	 try {
-            if (classDoc.dimension().equals(dim)) {
-               return classDoc;
-            }
-            else {
-               Type rc = (Type) ((WritableType)classDoc).clone();
-               ((WritableType)rc).setDimension(dim);
-               return rc;
-            }
-	 }
-	 catch (CloneNotSupportedException e) {
-	    throw new ParseException(e.toString());
-	 }
+      ClassDoc classDoc = findClass(typeName, dim);
+      if (null != classDoc) {
+         return classDoc;
       }
 
       Type type = (Type)typeMap.get(typeName+dim);
