@@ -69,6 +69,12 @@ public final class Main
    */
   static final int COVERAGE_PRIVATE = 3;
 
+  /*
+   *  FIXME: This should come from a ResourceBundle
+   */
+  private static final String STRING_TRY_GJDOC_HELP = 
+     "Try `gjdoc --help' for more information.";
+
   /**
    * Grid for looking up whether a particular access level is included in the
    * documentation.
@@ -376,6 +382,7 @@ public final class Main
               //--- Complain if not found
 
               reporter.printError("Unknown option " + option);
+              reporter.printNotice(STRING_TRY_GJDOC_HELP);
               return false;
             }
           }
@@ -546,11 +553,9 @@ public final class Main
 
       //--- Complain if no packages or classes specified
 
-      if (!rootDoc.hasSpecifiedPackagesOrClasses())
-      {
-        reporter.printError("No packages or classes specified.");
+      if (option_help) {
         usage();
-        return false;
+        return true;
       }
 
       //--- Validate custom options passed on command line
@@ -563,6 +568,13 @@ public final class Main
             { customOptionArr, reporter })).booleanValue())
       {
         // Not ok: shutdown system.
+        reporter.printNotice(STRING_TRY_GJDOC_HELP);
+        return false;
+      }
+
+      if (!rootDoc.hasSpecifiedPackagesOrClasses()) {
+        reporter.printError("No packages or classes specified.");
+        reporter.printNotice(STRING_TRY_GJDOC_HELP);
         return false;
       }
 
@@ -1126,7 +1138,9 @@ public final class Main
         rootDoc.setSourceEncoding(option_encoding);
       }
       else {
-        rootDoc.setSourceEncoding("US-ASCII"); // FIXME
+        // be quiet about this for now:
+        // reporter.printNotice("No encoding specified, using platform default: " + System.getProperty("file.encoding"));
+        rootDoc.setSourceEncoding(System.getProperty("file.encoding"));
       }
       rootDoc.setSourcePath(option_sourcepath);
 
@@ -1535,7 +1549,7 @@ public final class Main
    */
   private static void usage()
   {
-    System.err
+    System.out
         .print("\n"
             + "USAGE: gjdoc [options] [packagenames] "
             + "[sourcefiles] [@files]\n\n"
@@ -1620,6 +1634,8 @@ public final class Main
             + "Gjdoc extension options:\n"
             + "  -reflection             Use reflection for resolving unqualified class names\n"
             + "  -licensetext            Include license text from source files\n"
+            + "  -validhtml              Use valid HTML/XML names (breaks compatibility)\n"
+            + "  -baseurl <url>          Hardwire the given base URL into generated pages\n"
                /**
             + "  -genhtml                Generate HTML code instead of XML code. This is the\n"
             + "                          default.\n"
